==> haskell-hls-explicit-fixity-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-Gi7BbYWRL4tCfJEHf11VGy
key:                  hls-explicit-fixity-plugin-2.1.0.0-Gi7BbYWRL4tCfJEHf11VGy
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  dbce4a9ed90eaa9a714b44324e14db6d
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-Gi7BbYWRL4tCfJEHf11VGy
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-9.6.6
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.1.0.0-Ev0UPIyWyNhJsmXEpq8uuf
key:                  hls-explicit-fixity-plugin-2.1.0.0-Ev0UPIyWyNhJsmXEpq8uuf
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  362669c1124867eaf628ba8e95b5cf49
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-fixity-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.1.0.0-Ev0UPIyWyNhJsmXEpq8uuf
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb ghc-9.6.6
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
